Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type NodeFeatureLister ¶ added in v0.12.0
type NodeFeatureLister interface {
// List lists all NodeFeatures in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.NodeFeature, err error)
// NodeFeatures returns an object that can list and get NodeFeatures.
NodeFeatures(namespace string) NodeFeatureNamespaceLister
NodeFeatureListerExpansion
}
NodeFeatureLister helps list NodeFeatures. All objects returned here must be treated as read-only.
func NewNodeFeatureLister ¶ added in v0.12.0
func NewNodeFeatureLister(indexer cache.Indexer) NodeFeatureLister
NewNodeFeatureLister returns a new NodeFeatureLister.
type NodeFeatureListerExpansion ¶ added in v0.12.0
type NodeFeatureListerExpansion interface{}
NodeFeatureListerExpansion allows custom methods to be added to NodeFeatureLister.
type NodeFeatureNamespaceLister ¶ added in v0.12.0
type NodeFeatureNamespaceLister interface {
// List lists all NodeFeatures in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.NodeFeature, err error)
// Get retrieves the NodeFeature from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.NodeFeature, error)
NodeFeatureNamespaceListerExpansion
}
NodeFeatureNamespaceLister helps list and get NodeFeatures. All objects returned here must be treated as read-only.
type NodeFeatureNamespaceListerExpansion ¶ added in v0.12.0
type NodeFeatureNamespaceListerExpansion interface{}
NodeFeatureNamespaceListerExpansion allows custom methods to be added to NodeFeatureNamespaceLister.
type NodeFeatureRuleLister ¶
type NodeFeatureRuleLister interface {
// List lists all NodeFeatureRules in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.NodeFeatureRule, err error)
// Get retrieves the NodeFeatureRule from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.NodeFeatureRule, error)
NodeFeatureRuleListerExpansion
}
NodeFeatureRuleLister helps list NodeFeatureRules. All objects returned here must be treated as read-only.
func NewNodeFeatureRuleLister ¶
func NewNodeFeatureRuleLister(indexer cache.Indexer) NodeFeatureRuleLister
NewNodeFeatureRuleLister returns a new NodeFeatureRuleLister.
type NodeFeatureRuleListerExpansion ¶
type NodeFeatureRuleListerExpansion interface{}
NodeFeatureRuleListerExpansion allows custom methods to be added to NodeFeatureRuleLister.