Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type NodeFeatureRuleLister ¶
type NodeFeatureRuleLister interface {
// List lists all NodeFeatureRules in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.NodeFeatureRule, err error)
// Get retrieves the NodeFeatureRule from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.NodeFeatureRule, error)
NodeFeatureRuleListerExpansion
}
NodeFeatureRuleLister helps list NodeFeatureRules. All objects returned here must be treated as read-only.
func NewNodeFeatureRuleLister ¶
func NewNodeFeatureRuleLister(indexer cache.Indexer) NodeFeatureRuleLister
NewNodeFeatureRuleLister returns a new NodeFeatureRuleLister.
type NodeFeatureRuleListerExpansion ¶
type NodeFeatureRuleListerExpansion interface{}
NodeFeatureRuleListerExpansion allows custom methods to be added to NodeFeatureRuleLister.
Click to show internal directories.
Click to hide internal directories.